@@ -1,4 +1,4 @@
-// Copyright (c) 2015-2016 Josh Blum
+// Copyright (c) 2015-2018 Josh Blum
 // SPDX-License-Identifier: BSL-1.0
 
 #include "SoapySocketDefs.hpp"
@@ -97,6 +97,15 @@ bool SoapyRPCSocket::null(void)
     return _sock == INVALID_SOCKET;
 }
 
+bool SoapyRPCSocket::status(void)
+{
+    int opt = 0;
+    socklen_t optlen = sizeof(opt);
+    ::getsockopt(_sock, SOL_SOCKET, SO_ERROR, (char *)&opt, &optlen);
+    if (opt != 0) this->reportError("getsockopt(SO_ERROR)", opt);
+    return opt == 0;
+}
+
 int SoapyRPCSocket::close(void)
 {
     if (this->null()) return 0;
@@ -431,7 +440,7 @@ int SoapyRPCSocket::recvfrom(void *buf, size_t len, std::string &url, int flags)
     socklen_t addrlen = sizeof(addr);
     int ret = ::recvfrom(_sock, (char *)buf, int(len), flags, (struct sockaddr*)&addr, &addrlen);
     if (ret == -1) this->reportError("recvfrom()");
-    else url = SoapyURL(SockAddrData((struct sockaddr *)&addr, addrlen)).toString();
+    else url = SoapyURL((struct sockaddr *)&addr).toString();
     return ret;
 }
 
@@ -491,7 +500,7 @@ std::string SoapyRPCSocket::getsockname(void)
     int ret = ::getsockname(_sock, (struct sockaddr *)&addr, &addrlen);
     if (ret == -1) this->reportError("getsockname()");
     if (ret != 0) return "";
-    return SoapyURL(SockAddrData((struct sockaddr *)&addr, addrlen)).toString();
+    return SoapyURL((struct sockaddr *)&addr).toString();
 }
 
 std::string SoapyRPCSocket::getpeername(void)
@@ -501,7 +510,7 @@ std::string SoapyRPCSocket::getpeername(void)
     int ret = ::getpeername(_sock, (struct sockaddr *)&addr, &addrlen);
     if (ret == -1) this->reportError("getpeername()");
     if (ret != 0) return "";
-    return SoapyURL(SockAddrData((struct sockaddr *)&addr, addrlen)).toString();
+    return SoapyURL((struct sockaddr *)&addr).toString();
 }
 
 int SoapyRPCSocket::setBuffSize(const bool isRecv, const size_t numBytes)
